pub struct GitHubReleaseUpdate {
pub repository: String,
pub current_version: String,
pub asset_suffix: String,
}Expand description
A GitHub release feed used to discover an application package.
Fields
repository: StringRepository in owner/name form.
current_version: StringVersion of the running application.
asset_suffix: StringFile-name suffix selected from the release assets, such as .apk.
Implementations