pub struct HostSurfaceSize {
pub width: f32,
pub height: f32,
pub scale: f32,
}Expand description
The size of the host surface, in logical pixels, with the scale the host renders it at.
Fields
width: f32Logical width.
height: f32Logical height.
scale: f32Physical pixels per logical pixel.
Implementations