pub fn launch_args() -> LaunchArgsRefExpand description
The launch arguments this app was started with.
The platform snapshot if one was installed, otherwise the command line.
pub fn launch_args() -> LaunchArgsRefThe launch arguments this app was started with.
The platform snapshot if one was installed, otherwise the command line.