pub struct SaveDocumentLauncher { /* private fields */ }Expand description
Presents the save-document chooser and hands the opened sink back.
Implementations
Sourceimpl SaveDocumentLauncher
impl SaveDocumentLauncher
Sourcepub fn launch(&self, request: SaveDocumentRequest)
pub fn launch(&self, request: SaveDocumentRequest)
Presents the chooser. A second call while one is in front is ignored.
Sourcepub fn is_in_flight(&self) -> bool
pub fn is_in_flight(&self) -> bool
Whether a chooser presented by this launcher is still in front.