pub struct PlaybackProgress {
pub position: Duration,
pub duration: Option<Duration>,
pub buffered: Duration,
}Expand description
Where the open item is.
Fields
position: DurationHow far in the item playback has reached.
duration: Option<Duration>The item’s length, or None for a stream that has none.
buffered: DurationHow far ahead of the position the buffer reaches. Equal to duration
for a local file, which is what makes a local file’s buffer bar full.
Implementations
Sourceimpl PlaybackProgress
impl PlaybackProgress
Sourcepub fn new(position: Duration, duration: Duration) -> PlaybackProgress
pub fn new(position: Duration, duration: Duration) -> PlaybackProgress
Progress through an item of known length.
Sourcepub fn fraction(&self) -> Option<f32>
pub fn fraction(&self) -> Option<f32>
How far through the item this is, or None when it has no length.
Sourcepub fn buffered_fraction(&self) -> Option<f32>
pub fn buffered_fraction(&self) -> Option<f32>
How much of the item is buffered, or None when it has no length.