pub fn network_monitor() -> NetworkMonitorRefExpand description
The active network monitor: the platform one if installed, else the default (online, unmetered).
pub fn network_monitor() -> NetworkMonitorRefThe active network monitor: the platform one if installed, else the default (online, unmetered).