pub enum PreferencesError {
Io(String),
Unavailable,
}Expand description
Errors produced by a preferences backend.
Variants
Io(String)
The backing store could not be read or written.
No durable storage is available on this platform or build.