pub struct FolderEntry {
pub name: String,
pub len: u64,
pub modified_millis: Option<u64>,
}Expand description
Display metadata for one file in a writable folder.
Fields
name: StringThe file name, as stored.
len: u64Byte length.
modified_millis: Option<u64>Last-modified time in milliseconds since the Unix epoch, when the provider reports one.