AppUpdateStatus

Enum AppUpdateStatus 

pub enum AppUpdateStatus {
    Idle,
    Checking,
    UpToDate,
    Available {
        package: UpdatePackage,
    },
    Downloading {
        downloaded: u64,
        total: Option<u64>,
    },
    Verifying,
    AwaitingConfirmation,
    Installing,
    Error(String),
}
Observable state of the application update flow.

Variants



Idle

No operation has started.



Checking

The release feed is being queried.



UpToDate

The running application is current.



Available

A package can be installed.

Fields

package: UpdatePackage

What the release feed offers, including its size and digest when it published them.



Downloading

A package is being transferred to the platform installer.

Fields

downloaded: u64

Bytes transferred so far.

total: Option<u64>

Total bytes when supplied by the server.



Verifying

The transfer finished and the package is being checked against the digest the release feed published.



AwaitingConfirmation

The platform is asking the user to approve installation.



Installing

The platform installer accepted the package.



Error(String)

The operation could not continue.