pub trait FolderReader: Send {
// Required method
fn read_chunk(&mut self) -> Result<Option<Vec<u8>>, FolderError>;
}Expand description
Chunked reader over one file in a writable folder.
Synchronous and Send so a worker thread can drain it.
Required Methods
Sourcefn read_chunk(&mut self) -> Result<Option<Vec<u8>>, FolderError>
fn read_chunk(&mut self) -> Result<Option<Vec<u8>>, FolderError>
Reads the next chunk, or None at end of file.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".